Learn R Programming

CREAM (version 1.1.1)

PeakMinFilt: PeakMinFilt is a function to filter the lowest Order of COREs which distance between functional regions is close to the corresponding Window Size

Description

PeakMinFilt is a function to filter the lowest Order of COREs which distance between functional regions is close to the corresponding Window Size

Usage

PeakMinFilt(Clusters_init, WindowVecFinal)

Arguments

Clusters_init

Table of indetified COREs before filteration

WindowVecFinal

Vector of window sizes ordered based on order of CORE

Value

Minimum order of COREs