PeakMinFilt is a function to filter the lowest Order of COREs which distance between functional regions is close to the corresponding Window Size
PeakMinFilt(Clusters_init, WindowVecFinal)Table of indetified COREs before filteration
Vector of window sizes ordered based on order of CORE
Minimum order of COREs